@@ -1,8 +1,10 @@
 # python imports
 import math
+import locale
 
 # django imports
 from django import template
+from django.conf import settings
 from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.urlresolvers import reverse
@@ -17,23 +19,24 @@ from lfs.catalog.models import Category
 from lfs.catalog.settings import PRODUCT_WITH_VARIANTS
 from lfs.catalog.settings import STANDARD_PRODUCT
 from lfs.catalog.settings import CONFIGURABLE_PRODUCT
-from lfs.page.models import Page
 from lfs.catalog.models import Product
 from lfs.catalog.models import PropertyOption
 from lfs.catalog.settings import PRODUCT_TYPE_LOOKUP
+import lfs.core.utils
 from lfs.core.models import Shop
 from lfs.core.models import Action
+from lfs.page.models import Page
 from lfs.shipping import utils as shipping_utils
 
 register = template.Library()
 
+
 @register.inclusion_tag('lfs/portlets/category_children.html', takes_context=True)
 def category_children(context, categories):
     """
     """
-    return {
-        "categories" : categories,
-    }
+    return {"categories": categories}
+
 
 @register.inclusion_tag('lfs/shop/google_analytics_tracking.html', takes_context=True)
 def google_analytics_tracking(context):
@@ -42,10 +45,11 @@ def google_analytics_tracking(context):
     """
     shop = lfs_get_object_or_404(Shop, pk=1)
     return {
-        "ga_site_tracking" : shop.ga_site_tracking,
-        "google_analytics_id" : shop.google_analytics_id,
+        "ga_site_tracking": shop.ga_site_tracking,
+        "google_analytics_id": shop.google_analytics_id,
     }
 
+
 @register.inclusion_tag('lfs/shop/google_analytics_ecommerce.html', takes_context=True)
 def google_analytics_ecommerce(context, clear_session=True):
     """Returns google analytics e-commerce tracking code. This should be
@@ -57,48 +61,52 @@ def google_analytics_ecommerce(context, clear_session=True):
 
     # The order is removed from the session. It has been added after the order
     # has been payed within the checkout process. See order.utils for more.
-    if clear_session and request.session.has_key("order"):
+    if clear_session and "order" in request.session:
         del request.session["order"]
 
-    if request.session.has_key("voucher"):
+    if "voucher" in request.session:
         del request.session["voucher"]
 
     return {
-        "order" : order,
-        "ga_ecommerce_tracking" : shop.ga_ecommerce_tracking,
-        "google_analytics_id" : shop.google_analytics_id,
+        "order": order,
+        "ga_ecommerce_tracking": shop.ga_ecommerce_tracking,
+        "google_analytics_id": shop.google_analytics_id,
     }
 
+
 def _get_shipping(context, product):
     request = context.get("request")
     if product.is_deliverable() == False:
         return {
-            "deliverable" : False,
-            "delivery_time" : shipping_utils.get_product_delivery_time(request, product.slug)
+            "deliverable": False,
+            "delivery_time": shipping_utils.get_product_delivery_time(request, product.slug)
         }
     else:
         return {
-            "deliverable" : True,
-            "delivery_time" : shipping_utils.get_product_delivery_time(request, product.slug)
+            "deliverable": True,
+            "delivery_time": shipping_utils.get_product_delivery_time(request, product.slug)
         }
 
+
 @register.inclusion_tag('lfs/shipping/shipping_tag.html', takes_context=True)
 def shipping(context, variant):
     return _get_shipping(context, variant)
 
+
 @register.inclusion_tag('lfs/catalog/sorting.html', takes_context=True)
 def sorting(context):
     """
     """
     request = context.get("request")
-    return {"current" : request.session.get("sorting")}
+    return {"current": request.session.get("sorting")}
+
 
 @register.inclusion_tag('lfs/catalog/breadcrumbs.html', takes_context=True)
 def breadcrumbs(context, obj):
     """
     """
     if isinstance(obj, Category):
-        cache_key = "category-breadcrumbs-%s" % obj.slug
+        cache_key = "%s-category-breadcrumbs-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, obj.slug)
         objects = cache.get(cache_key)
         if objects is not None:
             return objects
@@ -106,14 +114,14 @@ def breadcrumbs(context, obj):
         objects = []
         while obj is not None:
             objects.insert(0, {
-                "name" : obj.name,
-                "url"  : obj.get_absolute_url(),
+                "name": obj.name,
+                "url": obj.get_absolute_url(),
             })
             obj = obj.parent
 
         result = {
-            "objects" : objects,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
+            "objects": objects,
+            "STATIC_URL": context.get("STATIC_URL"),
         }
         cache.set(cache_key, result)
 
@@ -127,70 +135,45 @@ def breadcrumbs(context, obj):
             return []
         else:
             request = context.get("request")
-            category = lfs.catalog.utils.get_current_product_category(request, obj)
+            category = obj.get_current_category(request)
             if category is None:
                 return []
             else:
                 objects = [{
-                    "name" : obj.get_name(),
-                    "url"  : obj.get_absolute_url(),
+                    "name": obj.get_name(),
+                    "url": obj.get_absolute_url(),
                 }]
                 while category is not None:
                     objects.insert(0, {
-                        "name" : category.name,
-                        "url" : category.get_absolute_url(),
+                        "name": category.name,
+                        "url": category.get_absolute_url(),
                     })
                     category = category.parent
 
         result = {
-            "objects" : objects,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
+            "objects": objects,
+            "STATIC_URL": context.get("STATIC_URL"),
         }
 
     elif isinstance(obj, Page):
         objects = []
         objects.append({
             "name": _(u"Information"),
-            "get_absolute_url" : reverse("lfs_pages")})
+            "get_absolute_url": reverse("lfs_pages")}),
         objects.append({"name": obj.title})
 
         result = {
-            "objects" : objects,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
+            "objects": objects,
+            "STATIC_URL": context.get("STATIC_URL"),
         }
     else:
         result = {
-            "objects" : ({ "name" : obj }, ),
-            "MEDIA_URL" : context.get("MEDIA_URL"),
+            "objects": ({"name": obj},),
+            "STATIC_URL": context.get("STATIC_URL"),
         }
 
     return result
 
-@register.inclusion_tag('lfs/catalog/filter_navigation.html', takes_context=True)
-def filter_navigation(context, category):
-    """Displays the filter navigation portlet.
-    """
-    request = context.get("request")
-    sorting = request.session.get("sorting")
-
-    # Get saved filters
-    set_product_filters = request.session.get("product-filter", {})
-    set_product_filters = set_product_filters.items()
-    set_price_filters = request.session.get("price-filter")
-
-    # calculate filters
-    product_filters = lfs.catalog.utils.get_product_filters(category,
-        set_product_filters, set_price_filters, sorting)
-
-    price_filters = lfs.catalog.utils.get_price_filters(category,
-        set_product_filters, set_price_filters)
-
-    return {
-        "category" : category,
-        "product_filters" : product_filters,
-        "set_price_filters" : set_price_filters,
-        "price_filters" : price_filters,
-    }
 
 @register.inclusion_tag('lfs/catalog/product_navigation.html', takes_context=True)
 def product_navigation(context, product):
@@ -198,11 +181,14 @@ def product_navigation(context, product):
     """
     request = context.get("request")
     sorting = request.session.get("sorting", "price")
+    if sorting == "":
+        sorting = "price"
 
     slug = product.slug
 
-    cache_key = "product-navigation-%s" % slug
-    temp = None # cache.get(cache_key)
+    cache_key = "%s-product-navigation-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, slug)
+    temp = None  # cache.get(cache_key)
+
     if temp is not None:
         try:
             return temp[sorting]
@@ -218,9 +204,9 @@ def product_navigation(context, product):
         product = product.parent
         slug = product.slug
 
-    category = lfs.catalog.utils.get_current_product_category(request, product)
+    category = product.get_current_category(request)
     if category is None:
-        return {"display" : False }
+        return {"display": False}
     else:
         # First we collect all sub categories. This and using the in operator makes
         # batching more easier
@@ -233,37 +219,37 @@ def product_navigation(context, product):
         # So we have to take care for the product navigation too.
         if request.user.is_superuser:
             products = Product.objects.filter(
-                categories__in = categories,
-                sub_type__in = (STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
+                categories__in=categories,
+                sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
             ).order_by(sorting)
         else:
             products = Product.objects.filter(
-                categories__in = categories,
-                sub_type__in = (STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
-                active = True,
+                categories__in=categories,
+                sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
+                active=True,
             ).order_by(sorting)
 
         product_slugs = [p.slug for p in products]
         product_index = product_slugs.index(slug)
 
         if product_index > 0:
-            previous = product_slugs[product_index-1]
+            previous = product_slugs[product_index - 1]
         else:
             previous = None
 
         total = len(product_slugs)
-        if product_index < total-1:
-            next = product_slugs[product_index+1]
+        if product_index < total - 1:
+            next = product_slugs[product_index + 1]
         else:
             next = None
 
         result = {
-            "display" : True,
-            "previous" : previous,
-            "next" : next,
-            "current" : product_index+1,
-            "total" : total,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
+            "display": True,
+            "previous": previous,
+            "next": next,
+            "current": product_index + 1,
+            "total": total,
+            "STATIC_URL": context.get("STATIC_URL"),
         }
 
         temp[sorting] = result
@@ -271,13 +257,6 @@ def product_navigation(context, product):
 
         return result
 
-@register.inclusion_tag('lfs/catalog/sorting_portlet.html', takes_context=True)
-def sorting_portlet(context):
-    request = context.get("request")
-    return {
-        "current" : request.session.get("sorting"),
-        "MEDIA_URL" : context.get("MEDIA_URL"),
-    }
 
 class ActionsNode(Node):
     def __init__(self, group_name):
@@ -288,6 +267,7 @@ class ActionsNode(Node):
         context["actions"] = Action.objects.filter(active=True, group__name=self.group_name)
         return ''
 
+
 def do_actions(parser, token):
     """Returns the actions for the group with the given id.
     """
@@ -297,9 +277,9 @@ def do_actions(parser, token):
         raise TemplateSyntaxError(_('%s tag needs group id as argument') % bits[0])
 
     return ActionsNode(bits[1])
-
 register.tag('actions', do_actions)
 
+
 @register.inclusion_tag('lfs/shop/tabs.html', takes_context=True)
 def tabs(context, obj=None):
     """
@@ -323,10 +303,11 @@ def tabs(context, obj=None):
                 break
 
     return {
-        "tabs" : tabs,
-        "MEDIA_URL" : context.get("MEDIA_URL"),
+        "tabs": tabs,
+        "STATIC_URL": context.get("STATIC_URL"),
     }
 
+
 @register.inclusion_tag('lfs/catalog/top_level_categories.html', takes_context=True)
 def top_level_categories(context):
     """Displays the top level categories.
@@ -345,35 +326,15 @@ def top_level_categories(context):
             current = False
 
         categories.append({
-            "url" : category.get_absolute_url(),
-            "name" : category.name,
-            "current" : current,
+            "url": category.get_absolute_url(),
+            "name": category.name,
+            "current": current,
         })
 
     return {
-        "categories" : categories,
+        "categories": categories,
     }
 
-# @register.inclusion_tag('lfs/shop/menu.html', takes_context=True)
-# def menu(context):
-#     """
-#     """
-#     request = context.get("request")
-#     current_categories = get_current_categories(request)
-# 
-#     categories = []
-#     for category in Category.objects.filter(parent = None):
-#         categories.append({
-#             "id" : category.id,
-#             "slug" : category.slug,
-#             "name" : category.name,
-#             "selected" : category in current_categories
-#         })
-# 
-#     return {
-#         "categories" : categories,
-#         "MEDIA_URL" : context.get("MEDIA_URL"),
-#     }
 
 class TopLevelCategory(Node):
     """Calculates the current top level category.
@@ -386,6 +347,7 @@ class TopLevelCategory(Node):
         context["top_level_category"] = top_level_category.name
         return ''
 
+
 def do_top_level_category(parser, token):
     """Calculates the current top level category.
     """
@@ -395,9 +357,9 @@ def do_top_level_category(parser, token):
         raise TemplateSyntaxError(_('%s tag needs no argument') % bits[0])
 
     return TopLevelCategory()
-
 register.tag('top_level_category', do_top_level_category)
 
+
 class CartInformationNode(Node):
     """
     """
@@ -408,13 +370,14 @@ class CartInformationNode(Node):
             amount_of_items = 0
             price = 0.0
         else:
-            amount_of_items = cart.amount_of_items
-            price = lfs.cart.utils.get_cart_price(request, cart, total=True)
+            amount_of_items = cart.get_amount_of_items()
+            price = cart.get_price_gross(request, total=True)
 
         context["cart_amount_of_items"] = amount_of_items
         context["cart_price"] = price
         return ''
 
+
 def do_cart_information(parser, token):
     """Calculates cart informations.
     """
@@ -424,9 +387,9 @@ def do_cart_information(parser, token):
         raise TemplateSyntaxError(_('%s tag needs no argument') % bits[0])
 
     return CartInformationNode()
-
 register.tag('cart_information', do_cart_information)
 
+
 class CurrentCategoryNode(Node):
     """
     """
@@ -435,9 +398,10 @@ class CurrentCategoryNode(Node):
         product = context.get("product")
 
         context["current_category"] = \
-            lfs.catalog.utils.get_current_product_category(request, product)
+            product.get_current_category(request)
         return ''
 
+
 def do_current_category(parser, token):
     """Calculates current category.
     """
@@ -447,9 +411,9 @@ def do_current_category(parser, token):
         raise TemplateSyntaxError(_('%s tag needs product as argument') % bits[0])
 
     return CurrentCategoryNode()
-
 register.tag('current_category', do_current_category)
 
+
 # TODO: Move this to shop utils or similar
 def get_slug_from_request(request):
     """Returns the slug of the currently displayed category.
@@ -464,56 +428,33 @@ def get_slug_from_request(request):
 
     return slug
 
+
 @register.filter
-def currency(price, arg=None):
+def currency(value, grouping=True):
     """
+    e.g.
+    import locale
+    locale.setlocale(locale.LC_ALL, 'de_CH.UTF-8')
+    currency(123456.789)  # Fr. 123'456.79
+    currency(-123456.789) # <span class="negative">Fr. -123'456.79</span>
     """
-    if not price:
-        price = 0.0
-
-    # TODO: optimize
-    price = lfs.utils.misc.FormatWithCommas("%.2f", price)
-    shop = lfs_get_object_or_404(Shop, pk=1)
-    
-    if shop.get_default_country().code == "de":
-        # replace . and , for german format
-        a, b = price.split(".")
-        a = a.replace(",", ".")
-        price = "%s,%s EUR" % (a, b)
-    else:
-        price = "%s %s" % (price, shop.default_currency)
-
-    return price
+    shop = lfs.core.utils.get_default_shop()
+    result = locale.currency(value, grouping=grouping, international=shop.use_international_currency_code)
+    # add css class if value is negative
+    if value < 0:
+        # replace the minus symbol if needed
+        if result[-1] == '-':
+            length = len(locale.nl_langinfo(locale.CRNCYSTR))
+            result = '%s-%s' % (result[0:length], result[length:-1])
+        return '<span class="negative">%s</span>' % result
+    return result
 
 @register.filter
 def decimal_l10n(value):
-    """Localizes
+    """Returns the decimal value of value based on current locale.
     """
-    value = str(value)
-    shop = lfs_get_object_or_404(Shop, pk=1)
-    if shop.get_default_country().code == "de":
-        # replace . and , for german format
-        a, b = value.split(".")
-        a = a.replace(",", ".")
-        value = "%s,%s" % (a, b)
+    return locale.format_string("%.2f", value)
 
-    return value
-
-@register.filter
-def number(price, arg=None):
-    """
-    """
-    # TODO: optimize
-    price = lfs.utils.misc.FormatWithCommas("%.2f", price)
-    shop = lfs_get_object_or_404(Shop, pk=1)
-
-    if shop.get_default_country().code == "de":
-        # replace . and , for german format
-        a, b = price.split(".")
-        a = a.replace(",", ".")
-        price = "%s,%s" % (a, b)
-
-    return price
 
 @register.filter
 def quantity(quantity):
@@ -526,6 +467,7 @@ def quantity(quantity):
     else:
         return int(float(quantity))
 
+
 @register.filter
 def sub_type_name(sub_type, arg=None):
     """Returns the sub type name for the sub type with passed sub_type id.
@@ -535,12 +477,14 @@ def sub_type_name(sub_type, arg=None):
     except KeyError:
         return ""
 
+
 @register.filter
 def multiply(score, pixel):
     """Returns the result of score * pixel
     """
     return score * pixel
 
+
 @register.filter
 def option_name(option_id):
     """Returns the option name for option with passed id.
@@ -557,6 +501,7 @@ def option_name(option_id):
     else:
         return option.name
 
+
 @register.filter
 def option_name_for_property_value(property_value):
     """Returns the value or the option name for passed property_value
@@ -574,11 +519,27 @@ def option_name_for_property_value(property_value):
         else:
             return option.name
 
-    return property_value.value        
-    
+    return property_value.value
+
+
 @register.filter
 def packages(cart_item):
-    """Returns the packages based on product's package unit and cart items 
+    """Returns the packages based on product's package unit and cart items
     amount.
     """
-    return int(math.ceil(cart_item.amount / cart_item.product.packing_unit))
\ No newline at end of file
+    cart_item = cart_item.get("obj")
+    return int(math.ceil(cart_item.amount / cart_item.product.packing_unit))
+
+
+@register.filter(name='get_price')
+def get_price(product, request):
+    return product.get_price(request)
+
+
+@register.filter(name='get_for_sale_price')
+def get_for_sale_price(product, request):
+    return product.get_for_sale_price(request)
+
+@register.filter(name='get_standard_price')
+def get_standard_price(product, request):
+    return product.get_standard_price(request)
