@@ -1,8 +1,12 @@
 from django.conf.urls.defaults import *
 from django.views.generic.simple import direct_to_template
 
+urlpatterns = patterns('django.views.generic.simple',
+    (r'^products-new', 'direct_to_template', {'template': 'manage/new/product.html'}),
+)
+
 # General
-urlpatterns = patterns('lfs.manage.views',
+urlpatterns += patterns('lfs.manage.views',
     url(r'^$', "dashboard", name="lfs_manage_dashboard"),
 )
 
@@ -15,19 +19,23 @@ urlpatterns += patterns('lfs.manage.views.delivery_times',
 
 # Manufacturer
 urlpatterns += patterns('lfs.manage.views.manufacturer',
-    url(r'^manage/manufacturer-dispatcher$', "manufacturer_dispatcher", name="lfs_manufacturer_dispatcher"),
-    url(r'^manage/manufacturer/(?P<manufacturer_id>\d*)$', "manage_manufacturer", name="lfs_manufacturer"),
-    url(r'^manage/update-manufacturer-data/(?P<manufacturer_id>\d*)$', "update_data", name="lfs_manufacturer_update_manufacturer_data"),
-    url(r'^manage/add-manufacturer$', "add_manufacturer", name="lfs_manufacturer_add_manufacturer"),
-    url(r'^manage/delete-manufacturer/(?P<manufacturer_id>\d*)$', "delete_manufacturer", name="lfs_manufacturer_delete_manufacturer"),
-    url(r'^manage/edit-category-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "edit_category", name="lfs_manufacturer_edit_category"),
-    url(r'^manage/edit-product-manufacturer/(?P<manufacturer_id>\d*)/(?P<product_id>\d*)$', "edit_product", name="lfs_manufacturer_edit_product"),
-    url(r'^manage/category-state-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "category_state", name="lfs_manufacturer_category_state"),
-    url(r'^manage/manufacturer-inline/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "manufacturer_inline", name="lfs_manufacturer_inline"),
+    url(r'^manufacturer-dispatcher$', "manufacturer_dispatcher", name="lfs_manufacturer_dispatcher"),
+    url(r'^manufacturer/(?P<manufacturer_id>\d*)$', "manage_manufacturer", name="lfs_manufacturer"),
+    url(r'^update-manufacturer-data/(?P<manufacturer_id>\d*)$', "update_data", name="lfs_manufacturer_update_manufacturer_data"),
+    url(r'^add-manufacturer$', "add_manufacturer", name="lfs_manufacturer_add_manufacturer"),
+    url(r'^delete-manufacturer/(?P<manufacturer_id>\d*)$', "delete_manufacturer", name="lfs_manufacturer_delete_manufacturer"),
+    url(r'^edit-category-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "edit_category", name="lfs_manufacturer_edit_category"),
+    url(r'^edit-product-manufacturer/(?P<manufacturer_id>\d*)/(?P<product_id>\d*)$', "edit_product", name="lfs_manufacturer_edit_product"),
+    url(r'^category-state-manufacturer/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "category_state", name="lfs_manufacturer_category_state"),
+    url(r'^manufacturer-inline/(?P<manufacturer_id>\d*)/(?P<category_id>\d*)$', "manufacturer_inline", name="lfs_manufacturer_inline"),
 )
 
 # Marketing
 urlpatterns += patterns('lfs.manage.views.marketing',
+    url(r'^featured$', "marketing.manage_featured_page", name="lfs_manage_featured"),
+    url(r'^add-featured$', "featured.add_featured", name="lfs_manage_add_featured"),
+    url(r'^update-featured$', "featured.update_featured", name="lfs_manage_update_featured"),
+    url(r'^featured-inline$', "featured.manage_featured_inline", name="lfs_manage_featured_inline"),
     url(r'^marketing$', "marketing.manage_marketing", name="lfs_manage_marketing"),
     url(r'^manage-rating-mails$', "rating_mails.manage_rating_mails", name="lfs_manage_rating_mails"),
     url(r'^add-topseller$', "topseller.add_topseller", name="lfs_manage_add_topseller"),
@@ -73,6 +81,7 @@ urlpatterns += patterns('lfs.manage.views',
     url(r'^products-inline$', "products_inline", name="lfs_products_inline"),
     url(r'^save-products$', "save_products", name="lfs_manage_save_products"),
     url(r'^set-product-filters$', "set_filters", name="lfs_set_product_filters"),
+    url(r'^set-product-name-filter$', "set_name_filter", name="lfs_set_product_name_filter"),
     url(r'^reset-product-filters$', "reset_filters", name="lfs_reset_product_filters"),
     url(r'^set-products-page$', "set_products_page", name="lfs_set_products_page"),
 )
@@ -94,6 +103,7 @@ urlpatterns += patterns('lfs.manage.views.product.images',
     url(r'^update-images/(?P<product_id>\d*)$', "update_images", name="lfs_manage_update_images"),
     url(r'^product-images/(?P<product_id>\d*)$', "manage_images", name="lfs_manage_images"),
     url(r'^update-active-images/(?P<product_id>\d*)$', "update_active_images", name="lfs_manage_update_active_images"),
+    url(r'^move-image/(?P<id>\d+)$', "move_image", name="lfc_move_image"),
 )
 
 # Product SEO
@@ -117,8 +127,8 @@ urlpatterns += patterns('lfs.manage.views.product.variants',
 
 # Property Groups
 urlpatterns += patterns('lfs.manage.views.property_groups.property_groups',
-    url(r'^manage-property-groups', "manage_property_groups", name="lfs_manage_property_groups"),
-    url(r'^manage-property-group/(?P<id>\d*)', "manage_property_group", name="lfs_manage_property_group"),
+    url(r'^property-groups', "manage_property_groups", name="lfs_manage_property_groups"),
+    url(r'^property-group/(?P<id>\d*)', "manage_property_group", name="lfs_manage_property_group"),
     url(r'^add-property-group', "add_property_group", name="lfs_add_property_group"),
     url(r'^delete-property-group/(?P<id>\d*)', "delete_property_group", name="lfs_delete_property_group"),
     url(r'^assign-properties/(?P<group_id>\d*)', "assign_properties", name="lfs_assign_properties"),
@@ -132,29 +142,22 @@ urlpatterns += patterns('lfs.manage.views.property_groups.products',
     url(r'^pg-products-inline/(?P<product_group_id>\d*)', "products_inline", name="lfs_pg_products_inline"),
 )
 
-# Property Groups / Product Values
-urlpatterns += patterns('lfs.manage.views.property_groups.product_values',
-    url(r'^update-product-values/(?P<property_group_id>\d*)/', "update_product_values", name="lfs_update_product_values"),
-)
-
 # Shop Properties
 urlpatterns += patterns('lfs.manage.views.properties',
-    url(r'^manage-shop-properties$', "manage_properties", name="lfs_manage_shop_properties"),
-    url(r'^manage-shop-property/(?P<id>\d*)', "manage_property", name="lfs_manage_shop_property"),
+    url(r'^shop-properties$', "manage_properties", name="lfs_manage_shop_properties"),
+    url(r'^shop-property/(?P<id>\d*)', "manage_property", name="lfs_manage_shop_property"),
     url(r'^update-shop-property-type/(?P<id>\d*)', "update_property_type", name="lfs_update_shop_property_type"),
     url(r'^add-shop-property$', "add_property", name="lfs_add_shop_property"),
     url(r'^delete-shop-property/(?P<id>\d*)', "delete_property", name="lfs_delete_shop_property"),
     url(r'^add-shop-property-option/(?P<property_id>\d*)', "add_option", name="lfs_add_shop_property_option"),
     url(r'^add-shop-property-step/(?P<property_id>\d*)', "add_step", name="lfs_add_shop_property_step"),
-    url(r'^save-shop-property-step/(?P<property_id>\d*)', "save_step", name="lfs_save_shop_property_step"),
+    url(r'^save-shop-property-step/(?P<property_id>\d*)', "save_step_range", name="lfs_save_shop_property_step_range"),
     url(r'^save-shop-property-step-type/(?P<property_id>\d*)', "save_step_type", name="lfs_save_shop_property_step_type"),
     url(r'^delete-shop-property-option/(?P<id>\d*)', "delete_option", name="lfs_delete_shop_property_option"),
     url(r'^delete-shop-property-step/(?P<id>\d*)', "delete_step", name="lfs_delete_shop_property_step"),
 
     url(r'^save-number-field-validators/(?P<property_id>\d*)', "save_number_field_validators", name="lfs_save_number_field_validators"),
     url(r'^save-select-field/(?P<property_id>\d*)', "save_select_field", name="lfs_save_select_field"),
-
-
 )
 
 # Product properties
@@ -202,7 +205,6 @@ urlpatterns += patterns('lfs.manage.views.categories',
     url(r'^remove-products/(?P<category_id>\d*)$', "remove_products", name="lfs_manage_category_remove_products"),
     url(r'^add-top-category$', "add_category", name="lfs_manage_add_top_category"),
     url(r'^add-category/(?P<category_id>\d*)$', "add_category", name="lfs_manage_add_category"),
-    url(r'^update-category/(?P<category_id>\d*)$', "update_category"),
     url(r'^delete-category/(?P<id>[-\w]*)$', "delete_category", name="lfs_delete_category"),
     url(r'^products-inline/(?P<category_id>\d*)$', "products_inline", name="lfs_manage_category_products_inline"),
     url(r'^edit-category-data/(?P<category_id>\d*)$', "edit_category_data", name="lfs_manage_category_edit_data"),
@@ -230,15 +232,15 @@ urlpatterns += patterns('lfs.manage.views.customer',
 
 # Export
 urlpatterns += patterns('lfs.manage.views.export',
-	url(r'^export-dispatcher$', "export_dispatcher", name="lfs_export_dispatcher"),
-	url(r'^export/(?P<export_id>\d*)$', "manage_export", name="lfs_export"),
-	url(r'^export-inline/(?P<export_id>\d*)/(?P<category_id>\d*)$', "export_inline", name="lfs_export_inline"),
-	url(r'^edit-category/(?P<export_id>\d*)/(?P<category_id>\d*)$', "edit_category", name="lfs_export_edit_category"),
-	url(r'^edit-product/(?P<export_id>\d*)/(?P<product_id>\d*)$', "edit_product", name="lfs_export_edit_product"),
-	url(r'^category-state/(?P<export_id>\d*)/(?P<category_id>\d*)$', "category_state", name="lfs_export_category_state"),
-	url(r'^update-export-data/(?P<export_id>\d*)$', "update_data", name="lfs_export_update_export_data"),
-	url(r'^add-export$', "add_export", name="lfs_export_add_export"),
-	url(r'^delete-export/(?P<export_id>\d*)$', "delete_export", name="lfs_export_delete_export"),
+    url(r'^export-dispatcher$', "export_dispatcher", name="lfs_export_dispatcher"),
+    url(r'^export/(?P<export_id>\d*)$', "manage_export", name="lfs_export"),
+    url(r'^export-inline/(?P<export_id>\d*)/(?P<category_id>\d*)$', "export_inline", name="lfs_export_inline"),
+    url(r'^edit-category/(?P<export_id>\d*)/(?P<category_id>\d*)$', "edit_category", name="lfs_export_edit_category"),
+    url(r'^edit-product/(?P<export_id>\d*)/(?P<product_id>\d*)$', "edit_product", name="lfs_export_edit_product"),
+    url(r'^category-state/(?P<export_id>\d*)/(?P<category_id>\d*)$', "category_state", name="lfs_export_category_state"),
+    url(r'^update-export-data/(?P<export_id>\d*)$', "update_data", name="lfs_export_update_export_data"),
+    url(r'^add-export$', "add_export", name="lfs_export_add_export"),
+    url(r'^delete-export/(?P<export_id>\d*)$', "delete_export", name="lfs_export_delete_export"),
     url(r'^export-export/(?P<slug>[-\w]*)$', "export", name="lfs_export_export"),
     url(r'^update-category-variants-option/(?P<export_id>\d*)/(?P<category_id>\d*)$', "update_category_variants_option", name="lfs_export_update_category_variants_option"),
 )
@@ -346,7 +348,7 @@ urlpatterns += patterns('lfs.manage.views.review',
 
 # Shop
 urlpatterns += patterns('lfs.manage.views.shop',
-    url(r'^manage-shop$', "manage_shop", name="lfs_manage_shop"),
+    url(r'^shop$', "manage_shop", name="lfs_manage_shop"),
     url(r'^save-shop-default-values$', "save_default_values", name="lfs_save_shop_default_values"),
 )
 
