@@ -8,6 +8,7 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.template.loader import render_to_string
+from django.views.decorators.http import require_POST
 from django.utils.translation import ugettext_lazy as _
 
 # lfs imports
@@ -21,8 +22,17 @@ from lfs.manage.views.categories.view import category_view
 from lfs.manage.views.categories.portlet import manage_categories_portlet
 from lfs.manage.views.lfs_portlets import portlets_inline
 
+
+class CategoryAddForm(ModelForm):
+    """Process form to add a category.
+    """
+    class Meta:
+        model = Category
+        fields = ("name", "slug")
+
+
 class CategoryForm(ModelForm):
-    """Process form to add/edit categories options.
+    """Process form to edit a category.
     """
     def __init__(self, *args, **kwargs):
         super(CategoryForm, self).__init__(*args, **kwargs)
@@ -33,12 +43,11 @@ class CategoryForm(ModelForm):
         except KeyError:
             context = None
 
-        self.fields["parent"].choices = _category_choices(context)
-
     class Meta:
         model = Category
-        fields = ("name", "slug", "parent", "position", "short_description",
-            "description", "exclude_from_navigation", "image", "static_block", )
+        fields = ("name", "slug", "short_description", "description",
+                  "exclude_from_navigation", "image", "static_block")
+
 
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_categories(request):
@@ -50,10 +59,11 @@ def manage_categories(request):
     except IndexError:
         url = reverse("lfs_manage_add_top_category")
     else:
-        url = reverse("lfs_manage_category", kwargs={"category_id" : category.id})
+        url = reverse("lfs_manage_category", kwargs={"category_id": category.id})
 
     return HttpResponseRedirect(url)
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def manage_category(request, category_id, template_name="manage/category/manage_category.html"):
     """Displays the form to manage the category with given category id.
@@ -61,15 +71,16 @@ def manage_category(request, category_id, template_name="manage/category/manage_
     category = Category.objects.get(pk=category_id)
 
     return render_to_response(template_name, RequestContext(request, {
-        "categories_portlet" : manage_categories_portlet(request, category_id),
-        "category" : category,
-        # "products" : manage_products(request, category.id),
-        "data" : category_data(request, category_id),
-        "seo" : edit_seo(request, category_id),
-        "view" : category_view(request, category_id),
-        "portlets" : portlets_inline(request, category),
+        "categories_portlet": manage_categories_portlet(request, category_id),
+        "category": category,
+        "data": category_data(request, category_id),
+        "seo": edit_seo(request, category_id),
+        "view": category_view(request, category_id),
+        "portlets": portlets_inline(request, category),
+        "dialog_message": _("Do you really want to delete the category <b>'%(name)s'</b> and all its sub categories?" % {"name": category.name}),
     }))
 
+
 @permission_required("core.manage_shop", login_url="/login/")
 def category_data(request, category_id, template_name="manage/category/data.html"):
     """Displays the core data for the category_id with passed category_id.
@@ -77,13 +88,18 @@ def category_data(request, category_id, template_name="manage/category/data.html
     This is used as a part of the whole category form.
     """
     category = Category.objects.get(pk=category_id)
-    form = CategoryForm(instance=category)
+
+    if request.method == "POST":
+        form = CategoryForm(data=request.POST, instance=category, files=request.FILES)
+    else:
+        form = CategoryForm(instance=category)
 
     return render_to_string(template_name, RequestContext(request, {
-        "category" : category,
-        "form" : form,
+        "category": category,
+        "form": form,
     }))
 
+
 # Actions
 @permission_required("core.manage_shop", login_url="/login/")
 def edit_category_data(request, category_id, template_name="manage/category/data.html"):
@@ -97,6 +113,7 @@ def edit_category_data(request, category_id, template_name="manage/category/data
         message = _(u"Category data have been saved.")
     else:
         message = _(u"Please correct the indicated errors.")
+        return manage_category(request, category.id)
 
     # Delete image
     if request.POST.get("delete_image"):
@@ -109,25 +126,12 @@ def edit_category_data(request, category_id, template_name="manage/category/data
         child.level = len(child.get_parents()) + 1
         child.save()
 
-    url = reverse("lfs_manage_category", kwargs={"category_id" : category_id})
+    # Update positions
+    manage_utils.update_category_positions(category.parent)
+
+    url = reverse("lfs_manage_category", kwargs={"category_id": category_id})
     return HttpResponseRedirect(url)
 
-    # There is a problem with json, when uploading an image and returning the
-    # form json encoded. This is only occurring when the image field is not
-    # empty.As a workaround we call this method as "normal" reauest (not ajax).
-
-    # TODO: Investigate this further
-
-    # form_html = render_to_string(template_name, RequestContext(request, {
-    #     "category" : category,
-    #     "form" : form,
-    # }))
-    #
-    # result = simplejson.dumps({
-    #     "message" : message,
-    #     "portlet" : manage_categories_portlet(request) }, cls = LazyEncoder)
-    #
-    # return HttpResponse(result)
 
 @permission_required("core.manage_shop", login_url="/login/")
 def add_category(request, category_id="", template_name="manage/category/add_category.html"):
@@ -142,69 +146,42 @@ def add_category(request, category_id="", template_name="manage/category/add_cat
             parent = None
 
     if request.method == "POST":
-        form = CategoryForm(data = request.POST, files=request.FILES)
+        form = CategoryAddForm(data=request.POST)
         if form.is_valid():
             new_category = form.save(commit=False)
             new_category.parent = parent
             new_category.position = 999
             if parent:
-                new_category.level = parent.level+1
+                new_category.level = parent.level + 1
             new_category.save()
 
             # Update positions
             manage_utils.update_category_positions(parent)
-            url = reverse("lfs_manage_category", kwargs={"category_id" : new_category.id})
+            url = reverse("lfs_manage_category", kwargs={"category_id": new_category.id})
             return HttpResponseRedirect(url)
     else:
-        form = CategoryForm(initial={"parent" : category_id })
+        form = CategoryAddForm(initial={"parent": category_id})
 
     return render_to_response(template_name, RequestContext(request, {
-        "categories_portlet" : manage_categories_portlet(request, category_id),
-        "category" : parent,
-        "form" : form
+        "next": request.REQUEST.get("next", request.META.get("HTTP_REFERER")),
+        "category": parent,
+        "form": form,
     }))
 
+
+@require_POST
 @permission_required("core.manage_shop", login_url="/login/")
 def delete_category(request, id):
     """Deletes category with given id.
     """
     category = lfs_get_object_or_404(Category, pk=id)
+    parent = category.parent
     category.delete()
+    manage_utils.update_category_positions(parent)
 
     url = reverse("lfs_manage_categories")
     return HttpResponseRedirect(url)
 
-@permission_required("core.manage_shop", login_url="/login/")
-def update_category(request, category_id):
-    """Updates category with given id. This is called after a position change
-    has been taken place.
-    """
-    try:
-        if category_id == "":
-            parent_category = None
-        else:
-            parent_category = Category.objects.get(pk=category_id)
-    except ObjectDoesNotExist:
-        pass
-    else:
-        sorted_category_ids = request.POST.getlist("categories")
-        for i, category_id in enumerate(sorted_category_ids):
-            if category_id == "":
-                continue
-            try:
-                id = category_id.split("_")[1]
-                category = Category.objects.get(pk=id)
-            except ValueError, ObjectDoesNotExist:
-                continue
-            else:
-                category.parent = parent_category
-                category.position = i
-                category.save()
-
-        if parent_category is not None:
-            manage_utils.update_category_positions(parent_category)
-
-    return HttpResponse("")
 
 # Privates
 def _category_choices(context):
@@ -212,18 +189,18 @@ def _category_choices(context):
     Note: context is the category for which the form is applied.
     """
     categories = [("", "-")]
-    for category in Category.objects.filter(parent = None):
+    for category in Category.objects.filter(parent=None):
         if context != category:
             categories.append((category.id, category.name))
             _category_choices_children(categories, category, context)
     return categories
 
+
 def _category_choices_children(categories, category, context, level=1):
     """Adds the children of the given category to categories.
     Note: context is the category for which the form is applied.
     """
     for category in category.category_set.all():
         if context != category:
-            categories.append((category.id, "%s %s" % ("-" * level, category.name)))
-            _category_choices_children(categories, category, context, level+1)
-
+            categories.append((category.id, "%s %s" % ("-" * level * 5, category.name)))
+            _category_choices_children(categories, category, context, level + 1)
