@@ -3,17 +3,44 @@ from datetime import datetime
 from datetime import timedelta
 
 # django imports
+from django.conf import settings
 from django.core.cache import cache
 from django.db.models import Q
 
 # lfs imports
 from lfs.catalog.models import Product
 from lfs.marketing.models import Topseller
+from lfs.marketing.models import ProductSales
 from lfs.order.models import Order
 from lfs.order.settings import CLOSED
 from lfs.order.models import OrderItem
 from django.db import connection
 
+
+def calculate_product_sales():
+    """Calculates and saves total product sales.
+    """
+    ProductSales.objects.all().delete()
+
+    products = {}
+    for order_item in OrderItem.objects.all():
+        if order_item.product.is_variant():
+            product = order_item.product.parent
+            if product is None:
+                continue
+        else:
+            product = order_item.product
+
+        if product.id not in products:
+            products[product.id] = [product, 0]
+        products[product.id][1] += order_item.product_amount
+
+    for product_id, data in products.items():
+        product, created = ProductSales.objects.get_or_create(product=data[0])
+        product.sales = data[1]
+        product.save()
+
+
 def get_orders(days=14):
     """Returns closed orders which are closed for given amount of days.
     """
@@ -22,10 +49,11 @@ def get_orders(days=14):
     orders = Order.objects.filter(state=CLOSED, state_modified__lte=limit)
     return orders
 
+
 def get_topseller(limit=5):
     """Returns products with the most sales. Limited by given limit.
     """
-    cache_key = "topseller"
+    cache_key = "%s-topseller" % settings.CACHE_MIDDLEWARE_KEY_PREFIX
     topseller = cache.get(cache_key)
     if topseller is not None:
         return topseller
@@ -35,7 +63,7 @@ def get_topseller(limit=5):
     cursor.execute("""SELECT product_id, sum(product_amount) as sum
                       FROM order_orderitem
                       GROUP BY product_id
-                      ORDER BY sum DESC limit %s""" % (limit*2))
+                      ORDER BY sum DESC limit %s""" % (limit * 2))
 
     products = []
     for topseller in cursor.fetchall():
@@ -63,13 +91,14 @@ def get_topseller(limit=5):
     cache.set(cache_key, products)
     return products
 
+
 def get_topseller_for_category(category, limit=5):
     """Returns products with the most sales withing given category. Limited by
     given limit.
     """
     # TODO: Check Django 1.1's aggregation
 
-    cache_key = "topseller-%s" % category.id
+    cache_key = "%s-topseller-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, category.id)
     topseller = cache.get(cache_key)
     if topseller is not None:
         return topseller
@@ -78,35 +107,13 @@ def get_topseller_for_category(category, limit=5):
     categories = [category]
     categories.extend(category.get_all_children())
     category_ids = [c.id for c in categories]
-    
-    # 2. Get all order items with products within these categories.
-    #    product__parent__categories is for variants
-    f = Q(product__parent__categories__in=category_ids) | \
-        Q(product__categories__in=category_ids)
-        
-    order_items = OrderItem.objects.filter(f)
-    
-    # 3. Calculate totals per product
-    products = {}
-    for order_item in order_items:
-        if order_item.product.is_active():
-            if not products.has_key(order_item.product.id):
-                products[order_item.product.id] = 0
-            products[order_item.product.id] += order_item.product_amount
 
-    # 4. Sort product ids on values
-    products = products.items()
-    products.sort(lambda a, b: cmp(b[1], a[1]))
-
-    objects = []
-    for product_id, quantity in products[:limit]:
-        try:
-            objects.append(Product.objects.get(pk=product_id))
-        except Product.DoesNotExist:
-            pass
+    # Get all the most saled products for this categories
+    pss = ProductSales.objects.filter(product__categories__in=category_ids).order_by("-sales")[:limit]
 
+    objects = [ps.product for ps in pss]
     for explicit_ts in Topseller.objects.filter(product__categories__in=category_ids):
-        
+
         if explicit_ts.product.is_active():
             # Remove explicit_ts if it's already in the object list
             if explicit_ts.product in objects:
@@ -118,6 +125,5 @@ def get_topseller_for_category(category, limit=5):
                 position = 0
             objects.insert(position, explicit_ts.product)
 
-    objects = objects[:limit]
     cache.set(cache_key, objects)
-    return objects
\ No newline at end of file
+    return objects[:limit]
