@@ -16,17 +16,18 @@ import lfs.payment.settings
 from lfs.criteria.models.criteria_objects import CriteriaObjects
 from lfs.tax.models import Tax
 
-
 # other imports
 from paypal.standard.ipn.models import PayPalIPN
 from paypal.standard.pdt.models import PayPalPDT
 
+
 class ActivePaymentMethodManager(models.Manager):
     """A manager which return just valid (aka selectable) shipping methods.
     """
     def active(self):
         return super(ActivePaymentMethodManager, self).get_query_set().filter(active=True)
 
+
 class PaymentMethod(models.Model):
     """Decides how products are paid.
 
@@ -64,25 +65,25 @@ class PaymentMethod(models.Model):
        is valid.
 
     - module
-       This module will be called to process the payment. If it is empty the 
+       This module will be called to process the payment. If it is empty the
        LFS' default one will be used.
 
     A payment method may have several criteria which decide whether the
     payment method is valid. It is valid if all criteria are true. Only active
     and valid payment methods are provided to the shop customer.
     """
-    name = models.CharField(_(u"Name"), blank=True, max_length=50)
     active = models.BooleanField(_(u"Active"), default=False)
+    priority = models.IntegerField(_(u"Priority"), default=0)
+    name = models.CharField(_(u"Name"), max_length=50)
     description = models.TextField(_(u"Description"), blank=True)
     note = models.TextField(_(u"note"), blank=True)
-    priority = models.IntegerField(_(u"Priority"), default=0)
     image = models.ImageField(_(u"Image"), upload_to="images", blank=True, null=True)
     tax = models.ForeignKey(Tax, verbose_name=_(u"Tax"), blank=True, null=True)
     price = models.FloatField(_(u"Price"), default=0.0)
     deletable = models.BooleanField(default=True)
     module = models.CharField(blank=True, max_length=100)
     type = models.PositiveSmallIntegerField(choices=lfs.payment.settings.PAYMENT_METHOD_TYPES_CHOICES, default=lfs.payment.settings.PM_PLAIN)
-    
+
     criteria_objects = generic.GenericRelation(CriteriaObjects,
         object_id_field="content_id", content_type_field="content_type")
 
@@ -94,6 +95,7 @@ class PaymentMethod(models.Model):
     def __unicode__(self):
         return self.name
 
+
 class PaymentMethodPrice(models.Model):
     """An additional price for a payment method.
 
@@ -134,10 +136,10 @@ class PaymentMethodPrice(models.Model):
 
 from lfs.order.models import Order
 
+
 class PayPalOrderTransaction(models.Model):
     order = models.ForeignKey(Order, unique=True)
     ipn = models.ManyToManyField(PayPalIPN)
 
 
-
-from listeners import *
\ No newline at end of file
+from listeners import *
